@@ -30,13 +30,19 @@
        data
      * GeomagFile /' '/
        data
-     * UserHookc/MAX_USERHOOKC*' '/
+     * UserHookc /MAX_USERHOOKC*' '/
        data
-     * UserHooki/MAX_USERHOOKI*99999999/
+     * UserHooki /MAX_USERHOOKI*99999999/
        data
-     * UserHookr/MAX_USERHOOKR*1.d65/
+     * UserHookr /MAX_USERHOOKR*1.d65/
        data
-     * AtmosFile/' '/
+     * AtmosFile /' '/
        data
-     * DpmFile/' '/
+     * DpmFile /' '/
+       data
+     * PercentEnv /' '/
+       data
+     * SharpEnv /' '/
+       data
+     * AtEnv /' '/
       end
