@@ -1,5 +1,6 @@
       subroutine xBgRun
       implicit none
+#include  "Zmaxdef.h"
 #include "Zmanagerp.h"
 #include "Ztrack.h"
 #include "Ztrackv.h"
@@ -8,10 +9,14 @@
 #include "Zobs.h"
 #include "Zobsp.h"
 #include "Zobsv.h"
+#include  "Zstackv.h"
       include "Zprivate.f"
       include "Zprivate2.f"
 
-      save rspec, lossrspec, lossrspec2, respec
+
+
+            
+      save rspec, lossrspec, arspec, respec
       save rzspec,  zfspec, rtspec1, rtspec2, retspec1, retspec2
       save rezspec,  rzfspec, rfspec, efspec, refspec
 
@@ -36,6 +41,7 @@ c                           3 ==> reached at inner boundery.
 
       real*8 r, Eloss, rinmu, cosang
       real*8 dedt, rho, dist, disto
+      real*8 aa
       real*8 wx, wy, wz, temp
       real   za
       real  de, Ek, f, molu
@@ -55,9 +61,11 @@ c     integer ndummy
       character*128 title
       character*96 evid(nsites)
       save evid
-      real*8 cog, sumne,  obstimes
+      real*8 cog, cog2, sumne,  obstimes, Savederg(5)
+      real*8 depth
+      logical dosort
       character*2  kd(3)
-      save obstimes
+      save obstimes,  depth
 
 c       keep this interface so that the difference between
 c       the one in ForTA/  and in FleshHist is in the next line
@@ -116,12 +124,26 @@ c
      *         "dEdxLat", "GeV/(g/cm^2)", .true., power2(j),
      *         "r", "m.u")
             enddo
-c                e+mu in the central region
-c            call kwhisti( lossrspec2(i), 0., 1.0, 20, b'00000')
          enddo   
       endif
 
 
+      if(tkarspec) then
+         do i = 1, ansites
+            do j = 1, 3           ! g,e,mu
+               call kwhisti2(arspec(j, i),
+     *              0.,  45.0, 8,     b'00010',
+     *              rmin, bin, nrbin,  b'00011' )
+cc             call kwhiststep2(arspec(j, i), 2)
+               call kwhistai2(arspec(j,i), 
+     *         "Lateral Dist. of "//ptcl(j)//" at  diff. azimuth",
+     *         "ar", "ptcls", .true.,  power(j), 
+     *         "azimuth", "deg", "r", "m.u")
+            enddo
+         enddo
+      endif
+         
+
 c
       if(tkrespec) then
          do i = 1, ansites
@@ -368,17 +390,20 @@ c     *  eneded at this moment.
 c     *  After this is executed, event generation starts.
 c     *
       entry xBgEvent
-
-
       call cqIncident(inci, angle)
-      write(*,'("i ",  i3,  i4, g13.4,3f11.7)') EventNo, inci.p.code,
-     *   inci.p.fm.e,  -angle.r(1),  -angle.r(2), -angle.r(3)      
-c      
+
+       write(*,'("i ",  i3,  i4, g13.4,3f11.7,f7.1)')
+     *    EventNo, inci.p.code,
+     *   inci.p.fm.e,  -angle.r(1),  -angle.r(2), -angle.r(3)
+
+
+
       do i = 1, NoOfASSites
          SumEloss(i) = 0.
          Ng(i) = 0.
          Ne(i) = 0.
          Nmu(i) = 0.
+         Nhad(i) = 0.
       enddo
 
       if(tklat) then
@@ -394,11 +419,18 @@ c
             do j = 1, 3
                call kwhistc(lossrspec(j,i))
             enddo
-c            call kwhistc(lossrspec2(i))
          enddo
       endif
 
 
+      if(tkarspec) then
+         do i = 1, ansites
+            do j = 1, 3
+               call kwhistc2(arspec(j,i))
+            enddo
+         enddo
+      endif
+
       if(tkrespec) then
          do i = 1, ansites
             do j = 1, 3
@@ -495,9 +527,24 @@ c     For id =2, you need not output the z value, because it is always
 c     0 (within the computational accuracy).
 c
 c     **************************
+
+
       obstimes = obstimes + 1.d0
-      if( mod(obstimes, 100000.d0) .eq. 0. ) then 
-         write(0, *) ' obstime=', obstimes, ' ptclE=',aTrack.p.fm.p(4)
+      if(mod(obstimes, 100000.d0) .eq. 0. ) then 
+         dosort=.false.
+         do i = 1, min(4,Stack_pos)
+            if(Stack(i).p.fm.p(4) .ne. Savederg(i)) then
+               Savederg(i)=Stack(i).p.fm.p(4) 
+               dosort=.true.
+            endif
+         enddo
+         if(dosort) then
+            call csortStack
+         endif
+         write(0, *) ' obstimes=', obstimes, ' ptclE=',aTrack.p.fm.p(4)
+         do i = 1, min(4,Stack_pos)
+            write(0,*)' stack tops=', Stack(i).p.fm.p(4)
+         enddo
       endif
 c     ***************
       code = aTrack.p.code
@@ -518,6 +565,8 @@ c     ***************
             Ne(ldep) = Ne(ldep) + aTrack.wgt
          elseif(code .eq. kmuon) then
             Nmu(ldep) = Nmu(ldep) + aTrack.wgt
+         elseif(code .le. 6) then
+            Nhad(ldep) = Nhad(ldep) +aTrack.wgt
          endif
 
          do i = 1, ansites
@@ -578,11 +627,12 @@ c                     see if this is > K.E
                Eloss = Ek
                dist = Eloss/dedt
             endif
-            Eloss = Eloss*10.       !  GeV/(g/cm2)
+            Eloss = Eloss*aTrack.wgt       !  GeV/(g/cm2)
             SumEloss(ldep)=SumEloss(ldep) + Eloss
          endif
+      endif
 c            ------------------
-               
+      if(id .eq. 2 .and. code .le. 3) then
 c          see if 'where' is specified for histogram
          do i = 1, ansites
             if( histdep(i) .eq. ldep )  then
@@ -591,7 +641,7 @@ c
                molu = ObsSites(ldep).mu
                rinmu = r/molu
                sr = rinmu
-               if( tklat .and. code .le. 3) then
+               if( tklat ) then
 c                    lateral
                   call kwhist(rspec(code, i), sr, 1.0 )
                endif
@@ -635,7 +685,7 @@ cc                        tempr = rbin(ic)/ObsSites(j).mu
 cc                     endif
 c                       by   all charged particles
                      call kwhist(lossrspec(3,i), tempr, de)
-c                     call kwhist(lossrspec2(i), tempr, de)
+
                      if( aTrack.p.code .eq.  kelec ) then
 c                          by electrons
                         call kwhist(lossrspec(1,i), tempr, de)
@@ -647,8 +697,17 @@ cc                  enddo
                endif          
 c                  end of eloss late
 
+               if(tkarspec) then
+c                    arspec
+                  aa=atan2(aTrack.pos.xyz.y,aTrack.pos.xyz.x)*
+     *             57.29577951308230 
+                  aa= mod(aa + 360.d0,   360.d0)
+                  if(aa .gt. 337.5d0) aa= aa-360.d0
+                  call kwhist2( arspec(code, i), sngl(aa), sr, 1.0)
+               endif
 
-               if( tkrespec .and. code .le. 3 ) then
+
+               if( tkrespec ) then
 c                  re spectrum
                   call kwhist2( respec(code, i), sr, Ek, 1.0)
                endif
@@ -690,31 +749,31 @@ c                  re spectrum
      *              sr, f, 1.0 )
                endif
 
-               if( tkrtspec .and. code .le. 3) then
+               if( tkrtspec ) then
                   call kwhist2( rtspec1(code, i), sr, 
      *              sngl( aTrack.t ), 1.0)
                   call kwhist2( rtspec2(code, i), sr, 
      *              sngl( aTrack.t ), 1.0)
                endif
 
-               if(tkretspec .and. code .le. 3) then
+               if(tkretspec ) then
                   call kwhist3( retspec1(code, i), sr,  Ek, 
      *                 sngl( aTrack.t ), 1.0)
                   call kwhist3( retspec2(code, i), sr,  Ek, 
      *                 sngl( aTrack.t ), 1.0)
                endif
 
-               if( tkrezspec .and. code .le. 3 ) then
+               if( tkrezspec ) then
                   call kwhist3( rezspec(code,i), sr, Ek, 
      *              sngl(wz),  1.0 ) 
                endif
 
-               if( tkrzfspec .and. code .le. 3) then
+               if( tkrzfspec ) then
                   call kwhist3( rzfspec(code, i),  sr, 
      *                 sngl(wz), f, 1.0)
                endif
 
-               if( tkrefspec .and. code .le. 3) then
+               if( tkrefspec ) then
                   call kwhist3( refspec(code, i),  sr, 
      *                 Ek, f, 1.0)
                endif
@@ -728,6 +787,8 @@ c                  re spectrum
 c     **************
       entry xEnEvent
 c     **************
+      call cqFirstID(depth)
+      depth = depth* 0.1     ! in g/cm2  First col depth.
 
       if(ObserveAS) then
          cog = 0.
@@ -738,25 +799,55 @@ c     **************
          enddo
          cog = cog/sumne
 
+         cog2 = 0.
+         sumne = 0.
+         do i = 1, NoOfASSites
+            if( ASObsSites(i).age .gt.
+     *          (2.0-ASObsSites(NoOfASSites).age))  then
+               cog2 = cog2 + ASObsSites(i).esize*ASDepthList(i)*0.1
+               sumne= sumne +ASObsSites(i).esize
+            endif
+         enddo
+         if(sumne .gt. 0.) then
+            cog2 = cog2/sumne
+         else
+c              too deep penetrate
+            cog2 = ASDepthList(NoOfASSites)*0.1
+         endif
+
+
+         if(fnoB .ge. 0 )  then
+            write(fnoB,
+     *      '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, f7.2, 2f7.0)')
+     *      EventNo,  inci.p.code,
+     *      inci.p.subcode, inci.p.charge,
+     *      inci.p.fm.e, -angle.r(1), -angle.r(2), -angle.r(3),
+     *      depth, cog, cog2
+         else
+            write(*,
+     *      '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, f7.2, 2f7.0)')
+     *      EventNo,  inci.p.code,
+     *      inci.p.subcode, inci.p.charge,
+     *      inci.p.fm.e, -angle.r(1), -angle.r(2), -angle.r(3),
+     *      depth, cog, cog2
+         endif
          do i = 1, NoOfASSites 
             if(fnoB .ge. 0) then
-               write(fnoB, '( i4, i3, i5,
-     *          1pE11.3, 0pf5.2, f5.2, 1pE11.3, 0pf7.1,
-     *          1p3E11.3, 0pf7.0)')
-     *          EventNo, i,
-     *          int( ASDepthList(i)*0.1 ),  
-     *          sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age),
-     *          ASDepthList(i)*0.1/cog, SumEloss(i),  
-     *          sngl(ASObsSites(i).mu), Ng(i), Ne(i), Nmu(i), cog
+               write(fnoB, '("t ", i3, 2f7.1,  2f6.3,
+     *         1p6E11.3)')
+     *          i, 
+     *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
+     *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
+     *          Ng(i), Ne(i), Nmu(i), Nhad(i),
+     *          ASObsSites(i).esize, SumEloss(i)  
             else
-               write(*, '( i4, i3, i5,
-     *          1pE11.3, 0pf5.2, f5.2, 1pE11.3, 0pf7.1,
-     *          1p3E11.3, 0pf7.0)')
-     *          EventNo, i,
-     *          int( ASDepthList(i)*0.1 ),  
-     *          sngl(ASObsSites(i).esize), sngl(ASObsSites(i).age),
-     *          ASDepthList(i)*0.1/cog, SumEloss(i),  
-     *          sngl(ASObsSites(i).mu), Ng(i), Ne(i), Nmu(i), cog
+               write(*, '("t ", i3, 2f7.1,  2f6.3,
+     *         1p6E11.3)')
+     *          i, 
+     *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
+     *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
+     *          Ng(i), Ne(i), Nmu(i), Nhad(i),
+     *          ASObsSites(i).esize, SumEloss(i)  
             endif
          enddo
       endif
@@ -772,8 +863,8 @@ c     **************
      *   '(i3, i5,  f5.2, f5.2,
      *   i5,  i4)')
      *   histdep(i), int( ASDepthList(j)*0.1 ),  
-     *   ASObsSites(j).age, ASDepthList(j)*0.1/cog,
-     *   int(ASObsSites(i).mu), int(cog)
+     *   ASObsSites(j).age, ASDepthList(j)*0.1/cog2,
+     *   int(ASObsSites(j).mu), int(cog2)
       enddo
 
 
@@ -800,17 +891,26 @@ c     **************
                call kwhistp( lossrspec(j, i), fno)
             enddo
          enddo
-       
 
-c         do i = 1, ansites
-c            call kwhists( lossrspec2(i), 0. )
-c            call kwhistev(lossrspec2d3(j,i), EventNo)
-c            call kwhistid( lossrspec2(i), evid(i)//' a'//' dEr2')
-c            call kwhistp( lossrspec2(i), fno)
-c         enddo
       endif
  120  continue
       
+      if(tkarspec) then
+         do j = 1, 3
+            do i = 1, ansites
+               call kwhists2( arspec(j, i), 0. )
+               call kwhistev2( arspec(j,i), EventNo)
+               call kwhistid2( arspec(j, i), evid(i))
+               k=histdep(i)
+               write(dirstr,'(a,"/d",i4, "/")') 
+     *              ptcl(j), int( ASDepthList(k)*0.1 )  
+               call kseblk(dirstr, "|", nstr)
+               call kwhistdir2(arspec(j, i),  dirstr)
+               call kwhistp2( arspec(j, i),  fno)
+            enddo
+         enddo
+      endif
+      
       if(tkrespec) then
          do j = 1, 3
             do i = 1, ansites
