@@ -34,11 +34,12 @@ c
 
 c     ************************************
       integer nmax
-      parameter (nmax = 12)
+      parameter (nmax = 13)
       real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
       real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
-      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
+      logical newfmt
+      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx, newfmt
 c     ************************************      
 
 c
@@ -135,16 +136,17 @@ c    #include "Zmanagerp.h"
       character*(*) filepath
       real*8 yearin
       integer klena
-      character*71 msg
+      character*65 msg
 
 
 c     ************************************
       integer nmax
-      parameter (nmax = 12)
+      parameter (nmax = 13)
       real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
       real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
-      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
+      logical newfmt
+      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx, newfmt
 c     ************************************      
 
       character*128 path
@@ -180,6 +182,9 @@ c         and branch
      *              .or. index(msg, 'IGRF') .gt. 0 ) then
 c            IGRF data
          call cgmgIgrf(devn, path, yearin)
+      elseif(index(msg, 'igrf') .gt. 0 ) then
+c            IGRF data; from 2005
+         call cgmgIgrf(devn, path, yearin)
       elseif(index(msg, 'WMM') .gt. 0) then
 c             DoD data
          call cgmgWmm(devn, path, yearin)
@@ -197,18 +202,19 @@ c     *************************
       real*8  yearin ! input. year of geomag.
 
       integer i, j, store, m, n
-      character*72  msg
+      character*65  msg
       character*90  msg2
       real*4 yearx,  dy, coef, g, h, dg, dh
 
 
 c     ************************************
       integer nmax
-      parameter (nmax = 12)
+      parameter (nmax = 13)
       real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
       real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
-      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
+      logical newfmt
+      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx, newfmt
 c     ************************************      
 
 
@@ -218,12 +224,24 @@ c     ************************************
 c       first find the appropriate year
       
       read(devn, '(a)', end=1000) msg
+
       do i=1, 10000
          do while( index(msg, 'DGRF') .eq. 0 .and.
-     *         index(msg, 'IGRF') .eq. 0 )
+     *         index(msg, 'IGRF') .eq. 0  .and.
+     *         index(msg, 'igrf') .eq. 0  )
             read(devn, '(a)', end=1000) msg
+
          enddo
-         read(msg, '(12x, f8.2)') yearx
+         if( index(msg, 'igrf') .ne. 0  ) then
+c              >= 2005
+            newfmt = .true.
+            read(devn, '(a65)', end=1000) msg
+            read(msg, '(12x, f6.1)') yearx
+         else
+            newfmt = .false.
+            read(msg, '(12x, f8.2)') yearx
+
+         endif
          if(store .eq. 0 .and.  yearin - yearx .lt. 5.0
      *      .and. yearin .ge. yearx) then
             store = store + 1
@@ -236,13 +254,21 @@ c       first find the appropriate year
          if( store .gt. 0 ) then
             do j = 1, 1000000
                read(devn, '(a)', end=1000) msg
+
                if( index(msg, 'DGRF') .gt. 0 .or.
-     *             index(msg, 'IGRF') .gt. 0 ) then
+     *             index(msg, 'IGRF') .gt. 0 .or.
+     *             index(msg, 'igrf') .gt. 0 ) then
 c                       new year appeared
                   goto 30  ! loop out
                else
-                  read(msg, '(2i2, 2f8.1,2f8.2)')
+                  if( newfmt ) then
+                     read(msg,  *) n, m, g, h  !  n, m are inverse of  old format
+                     dg = 0.
+                     dh = 0.
+                  else
+                     read(msg, '(2i2, 2f8.1,2f8.2)')
      *                 m, n, g, h, dg, dh
+                  endif
                   if( n .gt. nmax ) then
                      call cerrorMsg(msg, 1)
                      write(msg2,*)
@@ -327,11 +353,12 @@ c     *************************
 
 c     ************************************
       integer nmax
-      parameter (nmax = 12)
+      parameter (nmax = 13)
       real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
       real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
-      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
+      logical newfmt
+      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx, newfmt
 c     ************************************      
 
 
@@ -454,11 +481,12 @@ c        print current geomag coeff.
 
 c     ************************************
       integer nmax
-      parameter (nmax = 12)
+      parameter (nmax = 13)
       real*4 gnm(nmax, 0:nmax), hnm(nmax, nmax), year
       real*4 gnmd(nmax, 0:nmax), hnmd(nmax, nmax)
       integer nmx
-      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx
+      logical newfmt
+      common /ZmagCoef/  gnm, gnmd, hnm, hnmd, year, nmx, newfmt
 c     ************************************      
 
       write(*,*) 'year=',year, ' nmax=', nmx
