@@ -24,6 +24,8 @@ c            if(.not. (mod(HowGeomag, 10) .eq. 1 .and.     this existed from uv4
 c     *                Zfirst .eq. 0.)) then
              call cputEnergyLoss
 c               endif
+c                if "if" is omitted, segmentation violation
+c                may take place occasionally
              if(MoveStat .ne. Dead) then
                 call cputDeflection
              endif
@@ -423,7 +425,7 @@ c        for IBM AIX
       end
 
 c      ==============================================================
-       subroutine celecDef(dispx, dispy)
+       subroutine celecDef(dx, dy)
        implicit none
 
 #include  "Ztrack.h"
@@ -431,37 +433,88 @@ c      ==============================================================
 #include  "Ztrackv.h"
 #include  "Zelemagp.h"
 
-       real*8 dispx, dispy  ! output. scatttering displacement
-c
-       record /coord/ dircos
+      real*8 dx, dy             ! output. scatttering displacement
+c     
+      record /coord/ dircos
 c              by  Multiple Scattering
+      record /coord/ dsa   ! dire ccos of scattering angle
+      record /coord/ w
+      real*8  sint, cs, sn, tmp, avx, avy, disp, dt, dl
+      real*8 r, g1, g2, gf1, gf2, beta2, tetarms
+      real*8 theta
+      
+      call cmulScat(theta)
+      if(theta .lt. 0.01d0) then
+c                 cos
+         dsa.z = 1.-theta**2/2
+         sint = theta
+      else
+         dsa.z = cos(theta)
+         sint = sin(theta)
+      endif
+c        azimuthal angle
+      call kcossn(cs, sn)
+      dsa.x = sint * cs
+      dsa.y = sint * sn
+      dt = IntInfArray(ProcessNo).thickness/ X0 ! r.l
+      dl = IntInfArray(ProcessNo).length !  m
 
-       real*8 tetax, tetay
+      if(Moliere .ge. 0) then
+c         sample displacement correlated to theta
+c                 this is the same as P.D.B though look like
+c                diff.
+        tmp = dl/2.d0
+        avx = tmp * dsa.x
+        avy = tmp * dsa.y
+c                dispersion
+        gf1 = TrackBefMove.p.fm.p(4)/MovedTrack.p.mass
+        gf2 = MovedTrack.p.fm.p(4)/MovedTrack.p.mass
+        beta2 = 1.d0 - 1.d0/gf1/gf2
+        if(beta2 .le. 0.) then
+           disp = 0.d0
+        else
+           if(dt .gt. 1.d-3) then
+              tetarms = Es/TrackBefMove.p.fm.p(4)*
+     *            abs(MovedTrack.p.charge)*
+     *            sqrt(dt)*(1.0 + 0.038*log(dt))
+           else
+              tetarms = Es/TrackBefMove.p.fm.p(4)*
+     *                  abs(MovedTrack.p.charge)*
+     *              sqrt(dt)
+           endif
+           disp=tetarms/sqrt(6.d0*beta2)*dl/2.d0
+c               sample 2 independent gaussian variables
+c             with mean 0 and var 1
+        endif
+        call kgauss2(0.d0, 1.0d0, g1, g2)
+        dx = g1 * disp + avx
+        dy = g2 * disp + avy
+c                  displacement
+        r=sqrt(dx*dx+dy*dy)     ! in m
+c              direction cos of vector r in original sys.
+        if(r .ne. 0.) then
+           w.x = dx/r
+           w.y = dy/r
+           w.z = 0.
+c                 transform wx,wy,wz to original sys.
+c                    TrackBefMove is better
+           call ctransVectZ(TrackBefMove.vec.w, w, w)
+c               r is already in m.
+c              add scattering effect.
+c              r*w is displacement by scattering
+           MovedTrack.pos.xyz.x = r*w.x + MovedTrack.pos.xyz.x
+           MovedTrack.pos.xyz.y = r*w.y + MovedTrack.pos.xyz.y
+           MovedTrack.pos.xyz.z = r*w.z + MovedTrack.pos.xyz.z
+        endif
+      else
+         dx = 0.
+         dy = 0.
+      endif
+c        convert scattering angle at end of path to
+c        original system . MovedTrack is better since
+c        mag. def is contained there already.
+      call ctransVectZ(MovedTrack.vec.w, dsa,
+     *      MovedTrack.vec.w)
 
-       real*8 leng
-
-       integer i
-
-       leng = IntInfArray(ProcessNo).length
-
-c           Multiples csattering. around MovedTrack
-       call cmulScat(dispx, dispy, tetax, tetay)
-c
-c         form direction cos. if tx, ty are large, not correct.
-       call cvec2dcos(tetax, tetay, dircos)
-c
-c            new direction of moved particle in xyz system. 
-       call ctransVectZ(MovedTrack.vec.w,   dircos, 
-     *           MovedTrack.vec.w)
-c     +++++++++++++++++++++++++++++++++++++++++++++++++++++++
-c               displacement vector to direction cos
-       call cdispVec2Dcos(dispx, dispy, leng, dircos)
-c               in xyz system
-       call ctransVectZ(MovedTrack.vec.w, dircos, dircos)
-
-       do i = 1, 3
-          MovedTrack.pos.xyz.r(i) = MovedTrack.pos.xyz.r(i)  +
-     *         leng * dircos.r(i)
-       enddo
-       end
+      end
 
