@@ -180,8 +180,13 @@ c             the observation depth
          call cscalerProd(unitv, TrackBefMove.pos.xyz, r0r)
          if(seeupper) then
             obsrl = ObsSites(loc-1 ).pos.radiallen
+            if(loc .eq. 1)  MoveStat=BorderH
          else
             obsrl = ObsSites(loc).pos.radiallen
+            if(loc .eq. NoOfSites+1 )then
+c                this seems not needed.
+               MoveStat = BorderL
+            endif
          endif
 c            get distance to the crossing point
          if(rp .gt. obsrl ) then
