@@ -33,9 +33,9 @@ c           fin==1-->  all events generated
          if(fin .eq. 1) goto 10
 
 c          If ObsPlane != spherical, fix angle at observation level
-c          in detector system.'
+c          in detector system.
 c          If ObsPlane = spherical, do the same tentatively.
-c            (in this case Za1ry == 'is' guaranteed).
+c            (in this case Za1ry == 'is' or 'cos' guaranteed).
 
          call csPrimAng(angle)
          call cmkInc(incident, angle)
@@ -152,8 +152,20 @@ c            convert its direction to direction cos
          call c3DV2DDCos(incipos, dir1, len)
 c            sample angle around dir1 (x,y axes arbitrary)
          call rndc(u)
-         dir2.r(3) =  -(  (IMAG_P(CosZenith)- real(CosZenith) )*u +
+         if(Za1ry .eq. 'is') then
+            dir2.r(3) =  -(  (IMAG_P(CosZenith)- real(CosZenith) )*u +
      *             real(CosZenith) )    ! going down is negative
+         elseif(Za1ry .eq. 'cos') then
+c                  cos dcos
+            call ksampLin(1.0d0, 0.0d0, 
+     *       real(CosZenith), IMAG_P(CosZenith), dir2.r(3))
+            dir2.r(3) = -dir2.r(3) ! going down is negative
+         else
+            call cerrorMsg('Za1ry =', 1)
+            call cerrorMsg(Za1ry, 1)
+            call cerrorMsg(
+     *      ' for ObsPlane=3 is invalid; must be: "is" or "cos"',0)
+         endif
          call rndc(u)
          call kcossn(cs, sn)
          sint = sqrt(1.d0-dir2.r(3)**2)
